@@ -23,8 +23,6 @@ from gi.repository import GLib
 
 from setzer.app.service_locator import ServiceLocator
 
-import os.path
-
 
 class HeaderbarPresenter(object):
     ''' Mediator between workspace and view. '''
@@ -51,26 +49,13 @@ class HeaderbarPresenter(object):
         if change_code == 'new_active_document':
             document = parameter
 
-            if document.get_modified():
-                self.main_window.headerbar.save_document_button.set_sensitive(True)
-            elif document.get_filename() == None:
-                self.main_window.headerbar.save_document_button.set_sensitive(True)
-            else:
-                self.main_window.headerbar.save_document_button.set_sensitive(False)
-
             if document.is_latex_document():
                 self.activate_latex_documents_mode()
             elif document.is_bibtex_document():
                 self.activate_bibtex_documents_mode()
 
-            self.setup_modified_transform()
-
         if change_code == 'update_recently_opened_documents':
-            items = list()
             data = parameter.values()
-            for item in sorted(data, key=lambda val: -val['date']):
-                items.append(os.path.split(item['filename']))
-            self.main_window.headerbar.document_chooser.update_autosuggest(items)
             if len(data) > 0:
                 self.main_window.headerbar.open_document_button.set_sensitive(True)
                 self.main_window.headerbar.open_document_button.show_all()
@@ -111,6 +96,8 @@ class HeaderbarPresenter(object):
         self.main_window.headerbar.save_document_button.hide()
         self.main_window.headerbar.preview_toggle.hide()
         self.main_window.headerbar.preview_toggle.set_sensitive(False)
+        self.main_window.headerbar.help_toggle.hide()
+        self.main_window.headerbar.help_toggle.set_sensitive(False)
         self.main_window.headerbar.sidebar_toggle.hide()
         self.main_window.headerbar.sidebar_toggle.set_sensitive(False)
 
@@ -119,6 +106,8 @@ class HeaderbarPresenter(object):
         self.main_window.headerbar.save_document_button.show_all()
         self.main_window.headerbar.preview_toggle.show_all()
         self.main_window.headerbar.preview_toggle.set_sensitive(True)
+        self.main_window.headerbar.help_toggle.show_all()
+        self.main_window.headerbar.help_toggle.set_sensitive(True)
         self.main_window.headerbar.sidebar_toggle.show_all()
         self.main_window.headerbar.sidebar_toggle.set_sensitive(True)
 
@@ -127,6 +116,8 @@ class HeaderbarPresenter(object):
         self.main_window.headerbar.save_document_button.show_all()
         self.main_window.headerbar.preview_toggle.hide()
         self.main_window.headerbar.preview_toggle.set_sensitive(False)
+        self.main_window.headerbar.help_toggle.hide()
+        self.main_window.headerbar.help_toggle.set_sensitive(False)
         self.main_window.headerbar.sidebar_toggle.hide()
         self.main_window.headerbar.sidebar_toggle.set_sensitive(False)
 
@@ -145,28 +136,4 @@ class HeaderbarPresenter(object):
             if document.build_widget.view.has_result():
                 document.build_widget.view.hide_timer(1600)
 
-    def setup_modified_transform(self):
-        headerbar = self.main_window.headerbar
-
-        document = self.workspace.get_active_document()
-        if document == None:
-            headerbar.save_document_button.set_sensitive(False)
-            self.main_window.save_all_action.set_enabled(False)
-        else:
-            doclist_item = document.document_switcher_item.view
-            if headerbar.center_widget.mod_binding != None: headerbar.center_widget.mod_binding.unbind()
-            headerbar.center_widget.mod_binding = doclist_item.mlabel.bind_property('label', headerbar.center_widget.document_mod_label, 'label', 0, self.modified_transform_func)
-
-    def modified_transform_func(self, binding, from_value, to_value=None):
-        headerbar = self.main_window.headerbar
-
-        if from_value == 'False' and headerbar.center_widget.document_folder_label.get_text() != '':
-            headerbar.save_document_button.set_sensitive(False)
-        else:
-            headerbar.save_document_button.set_sensitive(True)
-        if self.workspace.get_unsaved_documents() != None:
-            self.main_window.save_all_action.set_enabled(True)
-        else:
-            self.main_window.save_all_action.set_enabled(False)
-
 
