@@ -54,7 +54,7 @@ class ShortcutsBar(Gtk.HBox):
         
     def populate_right_toolbar(self):
         self.button_build_log = Gtk.ToggleToolButton()
-        self.button_build_log.set_icon_name('utilities-system-monitor-symbolic')
+        self.button_build_log.set_icon_name('build-log-symbolic')
         self.button_build_log.set_tooltip_text(_('Build log') + ' (F8)')
         self.button_build_log.get_child().set_can_focus(False)
         self.right_icons.insert(self.button_build_log, 0)
@@ -145,10 +145,10 @@ class ShortcutsBar(Gtk.HBox):
         box = Gtk.VBox()
         self.pmb.set_box_margin(box)
         self.pmb.add_header_button(box, _('Natbib Citations'))
-        for citation_style in [(_('Abbreviated'), '\\citet{•}'), (_('Abbreviated with Brackets'), '\\citep{•}'), ('Detailed', '\\citet*{•}'), ('Detailed with Brackets', '\\citep*{•}'), ('Alternative 1', '\\citealt{•}'), ('Alternative 2', '\\citealp{•}')]:
+        for citation_style in [(_('Abbreviated'), '\\citet{•}'), (_('Abbreviated with Brackets'), '\\citep{•}'), (_('Detailed'), '\\citet*{•}'), (_('Detailed with Brackets'), '\\citep*{•}'), (_('Alternative 1'), '\\citealt{•}'), (_('Alternative 2'), '\\citealp{•}')]:
             self.pmb.add_action_button(box, citation_style[0], 'win.insert-symbol', [citation_style[1]])
         self.pmb.add_separator(box)
-        for citation_style in [(_('Cite Author'), '\\citeauthor{•}'), (_('Cite Author Detailed'), '\\citeauthor*{•}'), ('Cite Year', '\\citeyear{•}'), ('Cite Year with Brackets', '\\citeyearpar{•}')]:
+        for citation_style in [(_('Cite Author'), '\\citeauthor{•}'), (_('Cite Author Detailed'), '\\citeauthor*{•}'), (_('Cite Year'), '\\citeyear{•}'), (_('Cite Year with Brackets'), '\\citeyearpar{•}')]:
             self.pmb.add_action_button(box, citation_style[0], 'win.insert-symbol', [citation_style[1]])
         stack.add_named(box, 'natbib_citations')
         box.show_all()
@@ -178,8 +178,9 @@ class ShortcutsBar(Gtk.HBox):
         self.pmb.add_separator(box)
         self.pmb.add_menu_button(box, _('Sectioning'), 'sectioning')
         self.pmb.add_separator(box)
-        self.pmb.add_action_button(box, _('Environment'), 'win.insert-before-after', ['\\begin{•}\n\t', '\n\\end{•}'], keyboard_shortcut='Ctrl+E')
+        self.pmb.add_action_button(box, _('Environment'), 'win.insert-before-after', ['\\begin{•}\n\t', '\n\\end{•}'], keyboard_shortcut=_('Ctrl') + '+E')
         self.pmb.add_action_button(box, _('Verbatim Environment'), 'win.insert-before-after', ['\\begin{verbatim}\n\t', '\n\\end{verbatim}'])
+        self.pmb.add_menu_button(box, _('List Environments'), 'list_environments')
         self.pmb.add_menu_button(box, _('Quotations'), 'quotations')
         self.pmb.add_separator(box)
         self.pmb.add_menu_button(box, _('Cross References'), 'cross_references')
@@ -191,7 +192,7 @@ class ShortcutsBar(Gtk.HBox):
         box = Gtk.VBox()
         self.pmb.set_box_margin(box)
         self.pmb.add_header_button(box, _('Font Styles'))
-        for font_style in [(_('Bold') + ' (\\textbf)', 'textbf', 'format-text-bold-symbolic', 'Ctrl+B'), (_('Italic') + ' (\\textit)', 'textit', 'format-text-italic-symbolic', 'Ctrl+I'), (_('Underline') + ' (\\underline)', 'underline', 'format-text-underline-symbolic', 'Ctrl+U'), (_('Sans Serif') + ' (\\textsf)', 'textsf', 'placeholder', None), (_('Typewriter') + ' (\\texttt)', 'texttt', 'placeholder', 'Ctrl+M'), (_('Small Caps') + ' (\\textsc)', 'textsc', 'placeholder', None), (_('Slanted') + ' (\\textsl)', 'textsl', 'placeholder', None), (_('Emphasis') + ' (\\emph)', 'emph', 'placeholder', 'Ctrl+Shift+E')]:
+        for font_style in [(_('Bold') + ' (\\textbf)', 'textbf', 'format-text-bold-symbolic', _('Ctrl') + '+B'), (_('Italic') + ' (\\textit)', 'textit', 'format-text-italic-symbolic', _('Ctrl') + '+I'), (_('Underline') + ' (\\underline)', 'underline', 'format-text-underline-symbolic', _('Ctrl') + '+U'), (_('Sans Serif') + ' (\\textsf)', 'textsf', 'placeholder', None), (_('Typewriter') + ' (\\texttt)', 'texttt', 'placeholder', _('Ctrl') + '+M'), (_('Small Caps') + ' (\\textsc)', 'textsc', 'placeholder', None), (_('Slanted') + ' (\\textsl)', 'textsl', 'placeholder', None), (_('Emphasis') + ' (\\emph)', 'emph', 'placeholder', _('Shift') + '+' + _('Ctrl') + '+E')]:
             icon_name = font_style[2]
             self.pmb.add_action_button(box, font_style[0], 'win.insert-before-after', ['\\' + font_style[1] + '{', '}'], icon_name=icon_name, keyboard_shortcut=font_style[3])
         stack.add_named(box, 'font_styles')
@@ -222,9 +223,10 @@ class ShortcutsBar(Gtk.HBox):
         for command in ['newpage', 'linebreak', 'pagebreak', 'bigskip', 'medskip', 'smallskip']:
             self.pmb.add_action_button(box, '\\' + command, 'win.insert-symbol', ['\\' + command])
         self.pmb.add_action_button(box, '\\vspace', 'win.insert-symbol', ['\\vspace{•}'])
-        self.pmb.add_action_button(box, _('New Line')+ ' (\\\\)', 'win.insert-symbol', ['\\\\\n'], keyboard_shortcut='Ctrl+Return')
+        self.pmb.add_action_button(box, _('New Line')+ ' (\\\\)', 'win.insert-symbol', ['\\\\\n'], keyboard_shortcut=_('Ctrl') + '+Return')
         stack.add_named(box, 'vertical_spacing')
         box.show_all()
+
         # international accents submenu
         box = Gtk.VBox()
         self.pmb.set_box_margin(box)
@@ -246,6 +248,17 @@ class ShortcutsBar(Gtk.HBox):
         stack.add_named(box, 'sectioning')
         box.show_all()
 
+        # list environments submenu
+        box = Gtk.VBox()
+        self.pmb.set_box_margin(box)
+        self.pmb.add_header_button(box, _('List Environments'))
+        for list_type in [[_('Bulleted List') + ' (itemize)', 'itemize'], [_('Numbered List') + ' (enumerate)', 'enumerate'], [_('List with Bold Labels') + ' (description)', 'description']]:
+            self.pmb.add_action_button(box, list_type[0], 'win.insert-before-after', ['\\begin{' + list_type[1] + '}\n\t', '\n\\end{' + list_type[1] + '}'])
+        self.pmb.add_separator(box)
+        self.pmb.add_action_button(box, _('List Item'), 'win.insert-symbol', ['\\item •'], keyboard_shortcut=_('Shift') + '+' + _('Ctrl') + '+I')
+        stack.add_named(box, 'list_environments')
+        box.show_all()
+
         # quotations submenu
         box = Gtk.VBox()
         self.pmb.set_box_margin(box)
@@ -308,16 +321,16 @@ class ShortcutsBar(Gtk.HBox):
         self.pmb.set_box_margin(box)
         self.pmb.add_action_button(box, _('Include AMS Packages'), 'win.add-packages', ['amsmath', 'amssymb', 'amsfonts', 'amsthm'])
         self.pmb.add_separator(box)
-        self.pmb.add_action_button(box, _('Inline Math Section') + ' ($ ... $)', 'win.insert-before-after', ['$ ', ' $'], keyboard_shortcut='Ctrl+Shift+M')
-        self.pmb.add_action_button(box, _('Display Math Section') + ' (\\[ ... \\])', 'win.insert-before-after', ['\\[ ', ' \\]'], keyboard_shortcut='Alt+Shift+M')
+        self.pmb.add_action_button(box, _('Inline Math Section') + ' ($ ... $)', 'win.insert-before-after', ['$ ', ' $'], keyboard_shortcut=_('Shift') + '+' + _('Ctrl') + '+M')
+        self.pmb.add_action_button(box, _('Display Math Section') + ' (\\[ ... \\])', 'win.insert-before-after', ['\\[ ', ' \\]'], keyboard_shortcut=_('Shift') + '+Alt' + '+M')
         self.pmb.add_menu_button(box, _('Math Environments'), 'math_environments')
         self.pmb.add_separator(box)
-        self.pmb.add_action_button(box, _('Subscript') + ' (_{})', 'win.insert-before-after', ['_{', '}'], keyboard_shortcut='Ctrl+Shift+D')
-        self.pmb.add_action_button(box, _('Superscript') + ' (^{})', 'win.insert-before-after', ['^{', '}'], keyboard_shortcut='Ctrl+Shift+U')
-        self.pmb.add_action_button(box, _('Fraction') + ' (\\frac)', 'win.insert-symbol', ['\\frac{•}{•}'], keyboard_shortcut='Alt+Shift+F')
-        self.pmb.add_action_button(box, _('Square Root') + ' (\\sqrt)', 'win.insert-before-after', ['\\sqrt{', '}'], keyboard_shortcut='Ctrl+Shift+Q')
-        self.pmb.add_action_button(box, '\\left', 'win.insert-symbol', ['\\left •'], keyboard_shortcut='Ctrl+Shift+L')
-        self.pmb.add_action_button(box, '\\right', 'win.insert-symbol', ['\\right •'], keyboard_shortcut='Ctrl+Shift+R')
+        self.pmb.add_action_button(box, _('Subscript') + ' (_{})', 'win.insert-before-after', ['_{', '}'], keyboard_shortcut=_('Shift') + '+' + _('Ctrl') + '+D')
+        self.pmb.add_action_button(box, _('Superscript') + ' (^{})', 'win.insert-before-after', ['^{', '}'], keyboard_shortcut=_('Shift') + '+' + _('Ctrl') + '+U')
+        self.pmb.add_action_button(box, _('Fraction') + ' (\\frac)', 'win.insert-symbol', ['\\frac{•}{•}'], keyboard_shortcut=_('Shift') + '+Alt' + '+F')
+        self.pmb.add_action_button(box, _('Square Root') + ' (\\sqrt)', 'win.insert-before-after', ['\\sqrt{', '}'], keyboard_shortcut=_('Shift') + '+' + _('Ctrl') + '+Q')
+        self.pmb.add_action_button(box, '\\left', 'win.insert-symbol', ['\\left •'], keyboard_shortcut=_('Shift') + '+' + _('Ctrl') + '+L')
+        self.pmb.add_action_button(box, '\\right', 'win.insert-symbol', ['\\right •'], keyboard_shortcut=_('Shift') + '+' + _('Ctrl') + '+R')
         self.pmb.add_separator(box)
         self.pmb.add_menu_button(box, _('Math Functions'), 'math_functions')
         self.pmb.add_menu_button(box, _('Math Font Styles'), 'math_font_styles')
@@ -332,7 +345,7 @@ class ShortcutsBar(Gtk.HBox):
         self.pmb.set_box_margin(box)
         self.pmb.add_header_button(box, _('Math Environments'))
         for environment in ['equation', 'equation*', 'align', 'align*', 'alignat', 'alignat*', 'flalign', 'flalign*', 'gather', 'gather*', 'multline', 'multline*']:
-            self.pmb.add_action_button(box, environment, 'win.insert-before-after', ['\\begin{' + environment + '}\n\t', '\n\\end{' + environment + '}'], keyboard_shortcut=('Ctrl+Shift+N' if environment == 'equation' else None))
+            self.pmb.add_action_button(box, environment, 'win.insert-before-after', ['\\begin{' + environment + '}\n\t', '\n\\end{' + environment + '}'], keyboard_shortcut=(_('Shift') + '+' + _('Ctrl') + '+N' if environment == 'equation' else None))
         self.pmb.add_separator(box)
         for environment in ['cases', 'split']:
             self.pmb.add_action_button(box, environment, 'win.insert-before-after', ['\\begin{' + environment + '}\n\t', '\n\\end{' + environment + '}'])
@@ -415,7 +428,6 @@ class ShortcutsBar(Gtk.HBox):
         self.pmb.add_action_button(box, _('Figure (image inside freestanding block)'), 'win.insert-symbol', ['\\begin{figure}\n\t\\begin{center}\n\t\t\\includegraphics[scale=1]{•}\n\t\t\\caption{•}\n\t\\end{center}\n\\end{figure}'])
         self.pmb.add_action_button(box, _('Inline Image'), 'win.insert-symbol', ['\\includegraphics[scale=1]{•}'])
         self.pmb.add_menu_button(box, _('Code Listing'), 'code_listing')
-        self.pmb.add_menu_button(box, _('List Environments'), 'list_environments')
         stack.add_named(box, 'main')
         box.show_all()
 
@@ -433,17 +445,6 @@ class ShortcutsBar(Gtk.HBox):
         stack.add_named(box, 'code_listing')
         box.show_all()
 
-        # list environments submenu
-        box = Gtk.VBox()
-        self.pmb.set_box_margin(box)
-        self.pmb.add_header_button(box, _('List Environments'))
-        for list_type in [[_('Bulleted List') + ' (itemize)', 'itemize'], [_('Numbered List') + ' (enumerate)', 'enumerate'], [_('List with Bold Labels') + ' (description)', 'description']]:
-            self.pmb.add_action_button(box, list_type[0], 'win.insert-before-after', ['\\begin{' + list_type[1] + '}\n\t', '\n\\end{' + list_type[1] + '}'])
-        self.pmb.add_separator(box)
-        self.pmb.add_action_button(box, _('List Item'), 'win.insert-symbol', ['\\item •'], keyboard_shortcut='Ctrl+Shift+I')
-        stack.add_named(box, 'list_environments')
-        box.show_all()
-
         button_wrapper = Gtk.ToolItem()
         self.insert_object_button = Gtk.MenuButton()
         self.insert_object_button.set_direction(Gtk.ArrowType.DOWN)
