@@ -24,11 +24,14 @@ from setzer.helpers.observable import Observable
 import setzer.workspace.workspace_presenter as workspace_presenter
 import setzer.workspace.workspace_controller as workspace_controller
 import setzer.workspace.preview_panel.preview_panel_presenter as preview_panel_presenter
+import setzer.workspace.help_panel.help_panel as help_panel
 import setzer.workspace.sidebar.sidebar as sidebar
 import setzer.workspace.build_log.build_log as build_log
 import setzer.workspace.headerbar.headerbar_presenter as headerbar_presenter
+import setzer.workspace.document_chooser.document_chooser_presenter as document_chooser_presenter
 import setzer.workspace.keyboard_shortcuts.shortcuts as shortcuts
 import setzer.workspace.document_switcher.document_switcher as document_switcher
+import setzer.workspace.actions.actions as actions
 from setzer.app.service_locator import ServiceLocator
 
 
@@ -54,10 +57,12 @@ class Workspace(Observable):
         self.inline_spellchecking = self.settings.get_value('preferences', 'inline_spellchecking')
         self.spellchecking_language_code = self.settings.get_value('preferences', 'spellchecking_language_code')
         self.dark_mode = self.settings.get_value('preferences', 'prefer_dark_mode')
+        self.invert_pdf = self.settings.get_value('preferences', 'invert_pdf')
 
         self.sidebar = sidebar.Sidebar()
         self.show_sidebar = self.settings.get_value('window_state', 'show_sidebar')
         self.sidebar_position = self.settings.get_value('window_state', 'sidebar_paned_position')
+        self.show_help = self.settings.get_value('window_state', 'show_help')
         self.show_preview = self.settings.get_value('window_state', 'show_preview')
         self.preview_position = self.settings.get_value('window_state', 'preview_paned_position')
         self.build_log = build_log.BuildLog(self)
@@ -66,9 +71,12 @@ class Workspace(Observable):
         self.shortcuts = shortcuts.Shortcuts(self)
 
     def init_workspace_controller(self):
+        self.actions = actions.Actions(self)
         self.presenter = workspace_presenter.WorkspacePresenter(self)
         self.headerbar = headerbar_presenter.HeaderbarPresenter(self)
+        self.document_chooser = document_chooser_presenter.DocumentChooserPresenter(self)
         self.preview_panel = preview_panel_presenter.PreviewPanelPresenter(self)
+        self.help_panel = help_panel.HelpPanel(self)
         self.document_switcher = document_switcher.DocumentSwitcher(self)
         self.controller = workspace_controller.WorkspaceController(self)
 
@@ -93,8 +101,9 @@ class Workspace(Observable):
         self.open_documents.append(document)
         if document.is_latex_document():
             self.open_latex_documents.append(document)
-            document.spellchecker.set_enabled(self.inline_spellchecking)
-            document.spellchecker.set_language(self.spellchecking_language_code)
+            document.set_invert_pdf(self.invert_pdf)
+        document.spellchecker.set_enabled(self.inline_spellchecking)
+        document.spellchecker.set_language(self.spellchecking_language_code)
         document.state_manager.load_document_state()
         self.add_change_code('new_document', document)
         self.update_recently_opened_document(document.get_filename(), notify=True)
@@ -141,9 +150,9 @@ class Workspace(Observable):
             self.add_document(document)
             if activate:
                 self.set_active_document(document)
-        if document.is_latex_document():
-            document.preview.set_pdf_filename_from_tex_filename(filename)
-        return document
+            return document
+        else:
+            return None
 
     def get_document_by_filename(self, filename):
         for document in self.open_documents:
@@ -192,6 +201,12 @@ class Workspace(Observable):
             return document
         return None
 
+    def get_open_documents_filenames(self):
+        pathnames = list()
+        for document in self.open_documents:
+            pathnames.append(document.get_filename())
+        return pathnames
+
     def update_recently_opened_document(self, filename, date=None, notify=True):
         if not isinstance(filename, str) or not os.path.isfile(filename):
             self.remove_recently_opened_document(filename)
@@ -244,6 +259,10 @@ class Workspace(Observable):
                         self.set_one_document_master(document)
                 for item in data['recently_opened_documents'].values():
                     self.update_recently_opened_document(item['filename'], item['date'], notify=False)
+                try:
+                    self.help_panel.search_results_blank = data['recently_help_searches']
+                except KeyError:
+                    pass
                 try:
                     recently_opened_session_files = data['recently_opened_session_files'].values()
                 except KeyError:
@@ -289,7 +308,8 @@ class Workspace(Observable):
             data = {
                 'open_documents': open_documents,
                 'recently_opened_documents': self.recently_opened_documents,
-                'recently_opened_session_files': self.recently_opened_session_files
+                'recently_opened_session_files': self.recently_opened_session_files,
+                'recently_help_searches': self.help_panel.search_results_blank
             }
             if self.master_document != None:
                 data['master_document_filename'] = self.master_document.get_filename()
@@ -358,7 +378,7 @@ class Workspace(Observable):
             else:
                 document.set_has_visible_build_system(False)
 
-    def set_show_sidebar(self, show_sidebar, animate=False):
+    def set_show_sidebar(self, show_sidebar):
         if show_sidebar != self.show_sidebar:
             self.show_sidebar = show_sidebar
             self.add_change_code('set_show_sidebar', show_sidebar)
@@ -366,22 +386,23 @@ class Workspace(Observable):
     def set_sidebar_position(self, sidebar_position):
         self.sidebar_position = sidebar_position
 
+    def set_show_preview_or_help(self, show_preview, show_help):
+        if show_preview != self.show_preview or show_help != self.show_help:
+            self.show_preview = show_preview
+            self.show_help = show_help
+            self.add_change_code('set_show_preview_or_help')
+
     def set_preview_position(self, preview_position):
         self.preview_position = preview_position
 
-    def set_build_log_position(self, build_log_position):
-        self.build_log_position = build_log_position
-
-    def set_show_preview(self, show_preview, animate=False):
-        if show_preview != self.show_preview:
-            self.show_preview = show_preview
-            self.add_change_code('set_show_preview', show_preview)
-
     def set_show_build_log(self, show_build_log):
         if show_build_log != self.show_build_log:
             self.show_build_log = show_build_log
             self.add_change_code('show_build_log_state_change', show_build_log)
 
+    def set_build_log_position(self, build_log_position):
+        self.build_log_position = build_log_position
+
     def get_show_build_log(self):
         if self.show_build_log != None:
             return self.show_build_log
@@ -394,18 +415,25 @@ class Workspace(Observable):
             self.settings.set_value('preferences', 'prefer_dark_mode', self.dark_mode)
             self.add_change_code('set_dark_mode', value)
 
+    def set_invert_pdf(self, value):
+        if self.invert_pdf != value:
+            self.invert_pdf = value
+            self.settings.set_value('preferences', 'invert_pdf', self.invert_pdf)
+            for document in self.open_latex_documents:
+                document.set_invert_pdf(self.invert_pdf)
+
     def set_inline_spellchecking(self, value):
         if self.inline_spellchecking != value:
             self.inline_spellchecking = value
             self.settings.set_value('preferences', 'inline_spellchecking', self.inline_spellchecking)
-            for document in self.open_latex_documents:
+            for document in self.open_documents:
                 document.spellchecker.set_enabled(value)
 
     def set_spellchecking_language(self, language_code):
         if self.spellchecking_language_code != language_code:
             self.spellchecking_language_code = language_code
             self.settings.set_value('preferences', 'spellchecking_language_code', self.spellchecking_language_code)
-            for document in self.open_latex_documents:
+            for document in self.open_documents:
                 document.spellchecker.set_language(language_code)
 
 
