@@ -15,17 +15,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>
 
-import gi
-gi.require_version('Gtk', '3.0')
-from gi.repository import GLib, Gio
-
-import setzer.helpers.helpers as helpers
 from setzer.app.service_locator import ServiceLocator
 
 
 class WorkspacePresenter(object):
     ''' Mediator between workspace and view. '''
-    
+
     def __init__(self, workspace):
         self.workspace = workspace
         self.main_window = ServiceLocator.get_main_window()
@@ -49,7 +44,7 @@ class WorkspacePresenter(object):
 
         if change_code == 'new_document':
             document = parameter
-            document.set_use_dark_scheme(helpers.is_dark_mode(self.main_window))
+            document.set_dark_mode(ServiceLocator.get_is_dark_mode())
 
             if document.is_latex_document():
                 self.main_window.notebook.append_page(document.view)
@@ -78,7 +73,7 @@ class WorkspacePresenter(object):
                 document.view.source_view.grab_focus()
                 try:
                     self.main_window.preview_paned_overlay.add_overlay(document.autocomplete.view)
-                    document.autocomplete.update_autocomplete_position()
+                    document.autocomplete.update()
                 except AttributeError: pass
 
                 self.update_latex_shortcuts_bar()
@@ -104,8 +99,20 @@ class WorkspacePresenter(object):
         if change_code == 'set_show_sidebar':
             self.animate_sidebar(parameter, True)
 
-        if change_code == 'set_show_preview':
-            self.animate_preview(parameter, True)
+        if change_code == 'set_show_preview_or_help':
+            if self.workspace.show_preview:
+                self.main_window.preview_help_stack.set_visible_child_name('preview')
+                self.focus_active_document()
+            elif self.workspace.show_help:
+                self.main_window.preview_help_stack.set_visible_child_name('help')
+                if self.main_window.help_panel.stack.get_visible_child_name() == 'search':
+                    self.main_window.help_panel.search_entry.set_text('')
+                    self.main_window.help_panel.search_entry.grab_focus()
+                else:
+                    self.focus_active_document()
+            else:
+                self.focus_active_document()
+            self.animate_preview(self.workspace.show_preview, self.workspace.show_help, True)
 
         if change_code == 'show_build_log_state_change':
             self.build_log_animate(parameter, True)
@@ -115,25 +122,15 @@ class WorkspacePresenter(object):
 
     def activate_blank_slate_mode(self):
         self.main_window.mode_stack.set_visible_child_name('blank_slate')
-        self.main_window.save_all_action.set_enabled(False)
-        self.main_window.spellchecking_action.set_enabled(False)
-        self.main_window.add_remove_packages_dialog_action.set_enabled(False)
         self.main_window.shortcuts_bar.button_build_log.get_child().set_sensitive(False)
-        self.set_document_actions_active(False)
 
     def activate_latex_documents_mode(self):
         self.main_window.mode_stack.set_visible_child_name('latex_documents')
         self.main_window.shortcuts_bar.button_build_log.get_child().set_sensitive(True)
-        self.set_document_actions_active(True)
-        self.main_window.spellchecking_action.set_enabled(True)
-        self.main_window.add_remove_packages_dialog_action.set_enabled(True)
 
     def activate_bibtex_documents_mode(self):
         self.main_window.mode_stack.set_visible_child_name('bibtex_documents')
         self.main_window.shortcuts_bar.button_build_log.get_child().set_sensitive(False)
-        self.set_document_actions_active(True)
-        self.main_window.spellchecking_action.set_enabled(False)
-        self.main_window.add_remove_packages_dialog_action.set_enabled(False)
 
     def update_latex_shortcuts_bar(self):
         document = self.workspace.active_document
@@ -154,27 +151,19 @@ class WorkspacePresenter(object):
         shortcuts_bar.current_bottom = document.view.shortcuts_bar_bottom
         shortcuts_bar.pack_end(document.view.shortcuts_bar_bottom, False, False, 0)
 
-    def set_document_actions_active(self, value):
-        self.main_window.save_as_action.set_enabled(value)
-        self.main_window.find_action.set_enabled(value)
-        self.main_window.find_next_action.set_enabled(value)
-        self.main_window.find_prev_action.set_enabled(value)
-        self.main_window.find_replace_action.set_enabled(value)
-        self.main_window.close_document_action.set_enabled(value)
-        self.main_window.close_all_action.set_enabled(value)
-        self.main_window.save_session_action.set_enabled(value)
-        self.main_window.insert_before_after_action.set_enabled(value)
-        self.main_window.insert_symbol_action.set_enabled(value)
-        self.main_window.insert_before_document_end_action.set_enabled(value)
-        self.main_window.include_bibtex_file_action.set_enabled(value)
-        self.main_window.include_latex_file_action.set_enabled(value)
-        self.main_window.add_packages_action.set_enabled(value)
-        self.main_window.document_wizard_action.set_enabled(value)
+    def focus_active_document(self):
+        active_document = self.workspace.get_active_document()
+        if active_document != None:
+            active_document.view.source_view.grab_focus()
 
     def on_realize(self, view=None, cr=None, user_data=None):
         if self.sidebars_initialized == False:
             self.animate_sidebar(self.workspace.show_sidebar, False)
-            self.animate_preview(self.workspace.show_preview, False)
+            if self.workspace.show_preview:
+                self.main_window.preview_help_stack.set_visible_child_name('preview')
+            elif self.workspace.show_help:
+                self.main_window.preview_help_stack.set_visible_child_name('help')
+            self.animate_preview(self.workspace.show_preview, self.workspace.show_help, False)
             self.build_log_animate(self.workspace.get_show_build_log(), False)
             self.sidebars_initialized = True
 
@@ -236,9 +225,9 @@ class WorkspacePresenter(object):
             self.main_window.sidebar_paned.set_position(end)
             if set_toggle: self.main_window.headerbar.sidebar_toggle.set_active(show_sidebar)
 
-    def animate_preview(self, show_preview=False, animate=False, set_toggle=True):
+    def animate_preview(self, show_preview=False, show_help=False, animate=False, set_toggle=True):
         def set_position_on_tick(paned, frame_clock_cb, user_data=None):
-            show_preview, set_toggle = user_data
+            show_preview, show_help, set_toggle = user_data
             now = frame_clock_cb.get_frame_time()
             if now < end_time and paned.get_position != end:
                 t = self.ease((now - start_time) / (end_time - start_time))
@@ -246,58 +235,63 @@ class WorkspacePresenter(object):
                 return True
             else:
                 paned.set_position(end)
-                if not show_preview:
-                    self.main_window.preview_panel.hide()
+                if not (show_preview or show_help):
+                    self.main_window.preview_help_stack.hide()
                     self.main_window.preview_visible = False
                 else:
-                    self.main_window.preview_paned.child_set_property(self.main_window.preview_panel, 'shrink', False)
+                    self.main_window.preview_paned.child_set_property(self.main_window.preview_help_stack, 'shrink', False)
                     self.main_window.preview_visible = True
                     self.workspace.set_preview_position(paned.get_position())
-                if set_toggle: self.main_window.headerbar.preview_toggle.set_active(show_preview)
+                if set_toggle:
+                    self.main_window.headerbar.preview_toggle.set_active(show_preview)
+                    self.main_window.headerbar.help_toggle.set_active(show_help)
                 self.preview_animating = False
                 return False
 
         if self.preview_animating: return
-        if self.main_window.preview_visible == show_preview: return
 
-        frame_clock = self.main_window.preview_paned.get_frame_clock()
-        duration = 200
+        if self.main_window.preview_visible != (show_preview or show_help):
+            frame_clock = self.main_window.preview_paned.get_frame_clock()
+            duration = 200
 
-        if show_preview:
-            self.main_window.preview_paned.get_style_context().remove_class('hidden-separator')
-            self.main_window.preview_paned.get_style_context().add_class('visible-separator')
-            end = self.workspace.preview_position
-            if end == -1:
-                end = self.main_window.preview_paned.get_allocated_width() / 2
-        else:
-            self.main_window.preview_paned.get_style_context().add_class('hidden-separator')
-            self.main_window.preview_paned.get_style_context().remove_class('visible-separator')
-            end = self.main_window.preview_paned.get_allocated_width()
-
-        if frame_clock != None and animate:
-            if show_preview:
-                start = self.main_window.preview_paned.get_allocated_width()
-                self.main_window.preview_panel.show_all()
+            if show_preview or show_help:
+                self.main_window.preview_paned.get_style_context().remove_class('hidden-separator')
+                self.main_window.preview_paned.get_style_context().add_class('visible-separator')
+                end = self.workspace.preview_position
+                if end == -1:
+                    end = self.main_window.preview_paned.get_allocated_width() / 2
             else:
-                start = self.workspace.preview_position
-            if start != end:
-                start_time = frame_clock.get_frame_time()
-                end_time = start_time + 1000 * duration
-                self.preview_animating = True
-                self.main_window.preview_paned.add_tick_callback(set_position_on_tick, (show_preview, set_toggle))
-                self.main_window.preview_paned.child_set_property(self.main_window.preview_panel, 'shrink', True)
-        else:
-            if show_preview:
-                if self.workspace.show_sidebar == False and self.main_window.sidebar.get_allocated_width() > 1:
-                    end -= self.main_window.sidebar.get_allocated_width()
-                self.main_window.preview_paned.child_set_property(self.main_window.preview_panel, 'shrink', False)
-                self.main_window.preview_visible = True
+                self.main_window.preview_paned.get_style_context().add_class('hidden-separator')
+                self.main_window.preview_paned.get_style_context().remove_class('visible-separator')
+                end = self.main_window.preview_paned.get_allocated_width()
+
+            if frame_clock != None and animate:
+                if show_preview or show_help:
+                    start = self.main_window.preview_paned.get_allocated_width()
+                    self.main_window.preview_help_stack.show_all()
+                else:
+                    start = self.workspace.preview_position
+                if start != end:
+                    start_time = frame_clock.get_frame_time()
+                    end_time = start_time + 1000 * duration
+                    self.preview_animating = True
+                    self.main_window.preview_paned.add_tick_callback(set_position_on_tick, (show_preview, show_help, set_toggle))
+                    self.main_window.preview_paned.child_set_property(self.main_window.preview_help_stack, 'shrink', True)
             else:
-                self.main_window.preview_paned.child_set_property(self.main_window.preview_panel, 'shrink', True)
-                self.main_window.preview_visible = False
-                self.main_window.preview_panel.hide()
-            self.main_window.preview_paned.set_position(end)
-            if set_toggle: self.main_window.headerbar.preview_toggle.set_active(show_preview)
+                if show_preview or show_help:
+                    if self.workspace.show_sidebar == False and self.main_window.sidebar.get_allocated_width() > 1:
+                        end -= self.main_window.sidebar.get_allocated_width() + 1
+                    self.main_window.preview_paned.child_set_property(self.main_window.preview_help_stack, 'shrink', False)
+                    self.main_window.preview_visible = True
+                else:
+                    self.main_window.preview_paned.child_set_property(self.main_window.preview_help_stack, 'shrink', True)
+                    self.main_window.preview_visible = False
+                    self.main_window.preview_help_stack.hide()
+                self.main_window.preview_paned.set_position(end)
+
+        if set_toggle:
+            self.main_window.headerbar.preview_toggle.set_active(show_preview)
+            self.main_window.headerbar.help_toggle.set_active(show_help)
 
     def build_log_animate(self, show_build_log=True, animate=False):
         def set_position_on_tick(paned, frame_clock_cb, user_data=None):
